@@ -25,10 +25,9 @@ try:
 except ImportError:
     Mapping = dict
 
-from phe import EncodedNumber
-from phe.util import invert, powmod, mulmod, getprimeover, isqrt
+from phe_cuda import EncodedNumber
+from phe_cuda.util import invert, powmod, mulmod, getprimeover, isqrt
 import gpu_lib as gpu_cal
-from test_gpu_lib import test_gxx
 # Paillier cryptosystem is based on integer factorisation.
 # The default is chosen to give a minimum of 128 bits of security.
 # https://www.keylength.com/en/4/
